Community
=========

.. card::
   :title: Community
   :is_head: true
   :link: https://www.apache.org/foundation/policies/conduct

   Welcome to GluonTS community. We strive to foster a collaborative and welcoming community. We
   expect all members to follow the `code of conduct <https://www.apache.org/foundation/policies/conduct>`__.


.. container:: cards

   .. card::
      :title: Github Issues
      :link: https://github.com/awslabs/gluon-ts/issues

      Feature requests, bug reports, design and roadmap discussion.


   .. card::
      :title: Github Projects
      :link: https://github.com/awslabs/gluon-ts/projects

      Active roadmaps, and current and past projects.


Interested in contributing to GluonTS? Check our contribution guide:

.. toctree::
   :maxdepth: 3

   devsetup
   contribute